@@ -1813,7 +1813,7 @@ void HandleEnterNotify(void)
     if (is_initial_ungrab_pending)
     {
       is_initial_ungrab_pending = False;
-      xcrossing_last_grab_window = None;
+      xcrossing_last_grab_window = NULL;
     }
     else if (Tmp_win && Tmp_win == xcrossing_last_grab_window)
     {
@@ -1837,7 +1837,9 @@ void HandleEnterNotify(void)
       StashEventTime(&d);
       if((d.xcrossing.mode==NotifyNormal)&&
 	 (d.xcrossing.detail!=NotifyInferior))
+      {
 	return;
+      }
     }
   }
 
@@ -1962,7 +1964,9 @@ void HandleLeaveNotify(void)
   /* Ignore LeaveNotify events while a window is resized or moved as a wire
    * frame; otherwise the window list may be screwed up. */
   if (Scr.flags.is_wire_frame_displayed)
+  {
     return;
+  }
   if (Event.xcrossing.mode != NotifyNormal)
   {
     /* Ignore events generated by grabbing or ungrabbing the pointer.  However,
