@@ -61,6 +61,7 @@ typedef struct _match
   char               **wm_command;
   int                 x, y, w, h, icon_x, icon_y;
   int                 x_max, y_max, w_max, h_max;
+  int                 width_defect_max, height_defect_max;
   int                 max_x_offset, max_y_offset;
   int                 desktop;
   int                 layer;
@@ -91,7 +92,7 @@ char *duplicate(const char *s)
 
   if (!s) return NULL;
   l = strlen(s);
-  r = (char *) malloc (sizeof(char)*(l+1));
+  r = (char *) safemalloc (sizeof(char)*(l+1));
   strncpy(r, s, l+1);
   return r;
 }
@@ -313,7 +314,7 @@ char *get_version_string()
    * in the stable branch, othervise saving sessions becomes useless */
   /*return CatString3(VERSION, ", ",__DATE__);*/
 
-  return "2.4-2";
+  return "2.4-4";
 }
 
 /*
@@ -431,18 +432,20 @@ SaveWindowStates(FILE *f)
       if (ewin->name)
         fprintf(f, "  [WM_NAME] %s\n", ewin->name);
 
-      if (!XGetCommand (dpy, ewin->w, &wm_command, &wm_command_count))
-      {
-	wm_command = NULL;
-	wm_command_count = 0;
-      }
-      if (wm_command && (wm_command_count > 0))
+      wm_command = NULL;
+      wm_command_count = 0;
+      if (XGetCommand(dpy, ewin->w, &wm_command, &wm_command_count) &&
+	  wm_command && wm_command_count > 0)
       {
         fprintf(f, "  [WM_COMMAND] %i", wm_command_count);
         for (i = 0; i < wm_command_count; i++)
           fprintf(f, " %s", unspace_string(wm_command[i]));
         fprintf(f, "\n");
-        XFreeStringList (wm_command);
+      }
+      if (wm_command)
+      {
+        XFreeStringList(wm_command);
+	wm_command = NULL;
       }
     } /* !window_role */
 
@@ -454,9 +457,10 @@ SaveWindowStates(FILE *f)
       save_g.y -= Scr.Vy;
     }
     fprintf(
-      f, "  [GEOMETRY] %i %i %i %i %i %i %i %i %i %i %i %i %i\n",
+      f, "  [GEOMETRY] %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i\n",
       save_g.x, save_g.y, save_g.width, save_g.height,
       ewin->max_g.x, ewin->max_g.y, ewin->max_g.width, ewin->max_g.height,
+      ewin->max_g_defect.width, ewin->max_g_defect.height,
       ewin->icon_g.x + ((!is_icon_sticky) ? Scr.Vx : 0),
       ewin->icon_g.y + ((!is_icon_sticky) ? Scr.Vy : 0),
       ewin->hints.win_gravity,
@@ -481,8 +485,8 @@ DisableRestoringState(void)
 void
 LoadWindowStates(char *filename)
 {
-  FILE               *f;
-  char                s[4096], s1[4096];
+  FILE *f;
+  char s[4096], s1[4096];
   int i, pos, pos1;
   unsigned long w;
 
@@ -520,7 +524,8 @@ LoadWindowStates(char *filename)
     {
       sscanf(s, "%*s %lx", &w);
       num_match++;
-      matches = realloc(matches, sizeof(Match) * num_match);
+      matches =
+	(Match *)saferealloc((void *)matches, sizeof(Match) * num_match);
       matches[num_match - 1].win = w;
       matches[num_match - 1].client_id = NULL;
       matches[num_match - 1].res_name = NULL;
@@ -537,6 +542,8 @@ LoadWindowStates(char *filename)
       matches[num_match - 1].y_max = 0;
       matches[num_match - 1].w_max = Scr.MyDisplayWidth;
       matches[num_match - 1].h_max = Scr.MyDisplayHeight;
+      matches[num_match - 1].width_defect_max = 0;
+      matches[num_match - 1].height_defect_max = 0;
       matches[num_match - 1].icon_x = 0;
       matches[num_match - 1].icon_y = 0;
       matches[num_match - 1].desktop = 0;
@@ -547,7 +554,7 @@ LoadWindowStates(char *filename)
     }
     else if (!strcmp(s1, "[GEOMETRY]"))
     {
-      sscanf(s, "%*s %i %i %i %i %i %i %i %i %i %i %i %i %i",
+      sscanf(s, "%*s %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i",
 	     &(matches[num_match - 1].x),
 	     &(matches[num_match - 1].y),
 	     &(matches[num_match - 1].w),
@@ -556,6 +563,8 @@ LoadWindowStates(char *filename)
 	     &(matches[num_match - 1].y_max),
 	     &(matches[num_match - 1].w_max),
 	     &(matches[num_match - 1].h_max),
+	     &(matches[num_match - 1].width_defect_max),
+	     &(matches[num_match - 1].height_defect_max),
 	     &(matches[num_match - 1].icon_x),
 	     &(matches[num_match - 1].icon_y),
 	     &(matches[num_match - 1].gravity),
@@ -620,8 +629,8 @@ LoadWindowStates(char *filename)
       sscanf(s, "%*s %i%n",
 	&matches[num_match - 1].wm_command_count, &pos);
       matches[num_match - 1].wm_command =
-	(char **) malloc (matches[num_match - 1].wm_command_count *
-			  sizeof (char *));
+	(char **) safemalloc (matches[num_match - 1].wm_command_count *
+			      sizeof (char *));
       for (i = 0; i < matches[num_match - 1].wm_command_count; i++)
       {
         sscanf (s+pos, "%s%n", s1, &pos1);
@@ -762,8 +771,16 @@ MatchWinToSM(FvwmWindow *ewin, int *do_shade, int *do_max)
 	SET_DO_SKIP_CIRCULATE(ewin, DO_SKIP_CIRCULATE(&(matches[i])));
 	SET_FOCUS_MODE(ewin, GET_FOCUS_MODE(&(matches[i])));
 	if (matches[i].wm_name)
+	{
+	  if (ewin->name)
+	  {
+	    free(ewin->name);
+	  }
 	  ewin->name = matches[i].wm_name;
+	}
       }
+      SET_PLACED_WB3(ewin,IS_PLACED_WB3(&(matches[i])));
+      SET_PLACED_BY_FVWM(ewin,IS_PLACED_BY_FVWM(&(matches[i])));
       *do_shade = IS_SHADED(&(matches[i]));
       *do_max = IS_MAXIMIZED(&(matches[i]));
       SET_ICON_MOVED(ewin, IS_ICON_MOVED(&(matches[i])));
@@ -794,6 +811,8 @@ MatchWinToSM(FvwmWindow *ewin, int *do_shade, int *do_max)
       ewin->max_g.y = matches[i].y_max;
       ewin->max_g.width = matches[i].w_max;
       ewin->max_g.height = matches[i].h_max;
+      ewin->max_g_defect.width = matches[i].width_defect_max;
+      ewin->max_g_defect.height = matches[i].height_defect_max;
       ewin->max_offset.x = matches[i].max_x_offset;
       ewin->max_offset.y = matches[i].max_y_offset;
       SET_STICKY(ewin, IS_STICKY(&(matches[i])));
@@ -828,8 +847,10 @@ static int saveStateFile(char *filename)
   if ((f = fopen(filename, "w")) == NULL)
     return 0;
 
-  fprintf(f, "# This file is generated by fvwm. It stores global and window states.\n");
-  fprintf(f, "# Normally, you must never delete this file, it will be auto-deleted.\n\n");
+  fprintf(f, "# This file is generated by fvwm."
+	  " It stores global and window states.\n");
+  fprintf(f, "# Normally, you must never delete this file,"
+	  " it will be auto-deleted.\n\n");
 
 #ifdef SESSION
   if (goingToRestart)
